ylmfab
======

Introduction
------------

ylmfab is a set of tools to ease the writting of fab files (fabric)
for deploying systems based on git repositories with particular branches
and revisions.

Installation
------------

Recommended way
~~~~~~~~~~~~~~~

    pip install ylmfab

From Github
~~~~~~~~~~~
You can install ylmfab directly from github:

    pip install -e git+git://github.com/yeleman/ylmfab.git#egg=ylmfab

